@@ -106,12 +106,11 @@ PrettyTable::register_application(pid_t pid, Glib::RefPtr<Gdk::Pixbuf> icon)
   ** table to be added later */
     if (ProcInfo* info = GsmApplication::get()->processes.find(pid))
     {
-      info.set_icon(icon);
+      info->set_icon(icon);
       // move the ref to the map
       this->apps[pid] = icon;
       procman_debug("WNCK OK for %u", unsigned(pid));
     }
-  } catch (const std::out_of_range& e) {}
 }
 
 
